/* -*- mode: js2; js2-basic-offset: 4; indent-tabs-mode: nil -*- */
/*

    Copyright (C) 2012-2015  Dieter Schärf <ds@dschaerf.de>

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program. If not, see <http://www.gnu.org/licenses/>.

 */

const Gettext = imports.gettext;

const Gio = imports.gi.Gio;

const Config = imports.misc.config;
const ExtensionUtils = imports.misc.extensionUtils;

const Extension = ExtensionUtils.getCurrentExtension();

const CURRENT_GETTEXT_DOMAIN = Extension.metadata['gettext-domain'];
const CURRENT_SETTINGS_SCHEMA = Extension.metadata['settings-schema'];

const GNOME_SHELL_VERSION = Config.PACKAGE_VERSION.split('.');

const _ = Gettext.domain(CURRENT_GETTEXT_DOMAIN).gettext;

function checkGSV(major, minor, revision) {
    if (GNOME_SHELL_VERSION[0] === major.toString() && GNOME_SHELL_VERSION[1] === minor.toString()) {
        if (!revision || GNOME_SHELL_VERSION[2] === revision.toString()) return true;
    }
    return false;
}

function getSettings(schema, dontCheckSchema) {
    schema = schema || CURRENT_SETTINGS_SCHEMA;
    let schemaDir = Extension.dir.get_child('schemas');
    let schemaSource;
    if (schemaDir.query_exists(null)) {
        schemaSource = Gio.SettingsSchemaSource.new_from_directory(schemaDir.get_path(), Gio.SettingsSchemaSource.get_default(), false);
    } else {
        schemaSource = Gio.SettingsSchemaSource.get_default();
    }
    let schemaObj = schemaSource.lookup(schema, true);
    if (!schemaObj) {
        if (dontCheckSchema) return null;
        throw new Error(_("Schema '%s' could not be found for extension '%s'. Please check your installation.").format(schema, Extension.metadata['uuid']));
    }
    return new Gio.Settings({ settings_schema: schemaObj });
}

function initTranslations(domain) {
    domain = domain || CURRENT_GETTEXT_DOMAIN;
    let localeDir = Extension.dir.get_child('locale');
    if (localeDir.query_exists(null)) {
        Gettext.bindtextdomain(domain, localeDir.get_path());
    } else {
        Gettext.bindtextdomain(domain, Config.LOCALEDIR);
    }
}
